==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/ExpansionPanel_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { Base, enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ExpansionPanelIndicatorPosition_$type } from "./ExpansionPanelIndicatorPosition";
/**
 * @hidden
 */
export let ExpansionPanel = /*@__PURE__*/ (() => {
    class ExpansionPanel extends BaseElement {
        constructor() {
            super(...arguments);
            this.f = new WCNativeHelper();
            this.j = null;
            this.opening = null;
            this.opened = null;
            this.closing = null;
            this.closed = null;
        }
        get g() {
            return this.f;
        }
        get nativeElement() {
            return this.j;
        }
        set nativeElement(a) {
            this.j = a;
            this.f.n = this.j;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get i() {
            let ret_ = this.g.m("open");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.g.u("open", value_);
        }
        get h() {
            let ret_ = this.g.m("disabled");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.g.u("disabled", value_);
        }
        get e() {
            let ret_ = this.g.m("indicatorPosition");
            ret_ = enumGetBox(ExpansionPanelIndicatorPosition_$type, EnumUtil.getEnumValue(ExpansionPanelIndicatorPosition_$type, this.g.f(ExpansionPanelIndicatorPosition_$type, ret_)));
            return EnumUtil.getEnumValue(ExpansionPanelIndicatorPosition_$type, ret_);
        }
        set e(a) {
            let value_ = enumGetBox(ExpansionPanelIndicatorPosition_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.g.u("indicatorPosition", value_);
        }
        openingChanged() {
            if (this.opening != null) {
                this.g.q("opening", (a) => this.opening(this, ExpansionPanelComponentEventArgs.b(a)));
            }
            else {
                this.g.t("opening");
            }
        }
        openedChanged() {
            if (this.opened != null) {
                this.g.q("opened", (a) => this.opened(this, ExpansionPanelComponentEventArgs.b(a)));
            }
            else {
                this.g.t("opened");
            }
        }
        closingChanged() {
            if (this.closing != null) {
                this.g.q("closing", (a) => this.closing(this, ExpansionPanelComponentEventArgs.b(a)));
            }
            else {
                this.g.t("closing");
            }
        }
        closedChanged() {
            if (this.closed != null) {
                this.g.q("closed", (a) => this.closed(this, ExpansionPanelComponentEventArgs.b(a)));
            }
            else {
                this.g.t("closed");
            }
        }
        n() {
            this.nativeElement.connectedCallback();
        }
        t() {
            this.nativeElement.toggle();
        }
        o() {
            this.nativeElement.hide();
        }
        s() {
            this.nativeElement.show();
        }
    }
    ExpansionPanel.$t = /*@__PURE__*/ markType(ExpansionPanel, 'ExpansionPanel', BaseElement.$);
    return ExpansionPanel;
})();
/**
 * @hidden
 */
export let ExpansionPanelComponentEventArgs = /*@__PURE__*/ (() => {
    class ExpansionPanelComponentEventArgs extends Base {
        constructor() {
            super(...arguments);
            this.a = null;
        }
        static b(a) {
            return ((() => {
                let $ret = new ExpansionPanelComponentEventArgs();
                $ret.a = a;
                return $ret;
            })());
        }
    }
    ExpansionPanelComponentEventArgs.$t = /*@__PURE__*/ markType(ExpansionPanelComponentEventArgs, 'ExpansionPanelComponentEventArgs');
    return ExpansionPanelComponentEventArgs;
})();

==> igniteui-react-18.3.0-beta.0.tgz: package/esm2015/lib/ExpansionPanel_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { Base, enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ExpansionPanelIndicatorPosition_$type } from "./ExpansionPanelIndicatorPosition";
/**
 * @hidden
 */
export let ExpansionPanel = /*@__PURE__*/ (() => {
    class ExpansionPanel extends BaseElement {
        constructor() {
            super(...arguments);
            this.f = new WCNativeHelper();
            this.j = null;
            this.opening = null;
            this.opened = null;
            this.closing = null;
            this.closed = null;
        }
        get g() {
            return this.f;
        }
        get nativeElement() {
            return this.j;
        }
        set nativeElement(a) {
            this.j = a;
            this.f.o = this.j;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get i() {
            let ret_ = this.g.n("open");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.g.v("open", value_);
        }
        get h() {
            let ret_ = this.g.n("disabled");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.g.v("disabled", value_);
        }
        get e() {
            let ret_ = this.g.n("indicatorPosition");
            ret_ = enumGetBox(ExpansionPanelIndicatorPosition_$type, EnumUtil.getEnumValue(ExpansionPanelIndicatorPosition_$type, this.g.f(ExpansionPanelIndicatorPosition_$type, ret_)));
            return EnumUtil.getEnumValue(ExpansionPanelIndicatorPosition_$type, ret_);
        }
        set e(a) {
            let value_ = enumGetBox(ExpansionPanelIndicatorPosition_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.g.v("indicatorPosition", value_);
        }
        openingChanged() {
            if (this.opening != null) {
                this.g.r("opening", (a) => this.opening(this, ExpansionPanelComponentEventArgs.b(a)));
            }
            else {
                this.g.u("opening");
            }
        }
        openedChanged() {
            if (this.opened != null) {
                this.g.r("opened", (a) => this.opened(this, ExpansionPanelComponentEventArgs.b(a)));
            }
            else {
                this.g.u("opened");
            }
        }
        closingChanged() {
            if (this.closing != null) {
                this.g.r("closing", (a) => this.closing(this, ExpansionPanelComponentEventArgs.b(a)));
            }
            else {
                this.g.u("closing");
            }
        }
        closedChanged() {
            if (this.closed != null) {
                this.g.r("closed", (a) => this.closed(this, ExpansionPanelComponentEventArgs.b(a)));
            }
            else {
                this.g.u("closed");
            }
        }
        n() {
            this.nativeElement.connectedCallback();
        }
        t() {
            this.nativeElement.toggle();
        }
        o() {
            this.nativeElement.hide();
        }
        s() {
            this.nativeElement.show();
        }
    }
    ExpansionPanel.$t = /*@__PURE__*/ markType(ExpansionPanel, 'ExpansionPanel', BaseElement.$);
    return ExpansionPanel;
})();
/**
 * @hidden
 */
export let ExpansionPanelComponentEventArgs = /*@__PURE__*/ (() => {
    class ExpansionPanelComponentEventArgs extends Base {
        constructor() {
            super(...arguments);
            this.a = null;
        }
        static b(a) {
            return ((() => {
                let $ret = new ExpansionPanelComponentEventArgs();
                $ret.a = a;
                return $ret;
            })());
        }
    }
    ExpansionPanelComponentEventArgs.$t = /*@__PURE__*/ markType(ExpansionPanelComponentEventArgs, 'ExpansionPanelComponentEventArgs');
    return ExpansionPanelComponentEventArgs;
})();
